@@ -9,7 +9,6 @@
 #ifndef KCOREDIRLISTER_H
 #define KCOREDIRLISTER_H
 
-#include "kdirnotify.h" // TODO KF6: remove
 #include "kfileitem.h"
 
 #include <QString>
@@ -58,11 +57,13 @@ class KIOCORE_EXPORT KCoreDirLister : public QObject
 
     Q_OBJECT
     Q_PROPERTY(bool autoUpdate READ autoUpdate WRITE setAutoUpdate)
-    Q_PROPERTY(bool showingDotFiles READ showingDotFiles WRITE setShowingDotFiles)
+    Q_PROPERTY(bool showHiddenFiles READ showHiddenFiles WRITE setShowHiddenFiles)
     Q_PROPERTY(bool dirOnlyMode READ dirOnlyMode WRITE setDirOnlyMode)
     Q_PROPERTY(bool delayedMimeTypes READ delayedMimeTypes WRITE setDelayedMimeTypes)
+    Q_PROPERTY(bool requestMimeTypeWhileListing READ requestMimeTypeWhileListing WRITE setRequestMimeTypeWhileListing)
     Q_PROPERTY(QString nameFilter READ nameFilter WRITE setNameFilter)
     Q_PROPERTY(QStringList mimeFilter READ mimeFilters WRITE setMimeFilter RESET clearMimeFilter)
+    Q_PROPERTY(bool autoErrorHandlingEnabled READ autoErrorHandlingEnabled WRITE setAutoErrorHandlingEnabled)
 
 public:
     /**
@@ -95,7 +96,7 @@ public:
     /**
      * Destroy the directory lister.
      */
-    virtual ~KCoreDirLister();
+    ~KCoreDirLister() override;
 
     /**
      * Run the directory lister on the given url.
@@ -109,11 +110,8 @@ public:
      * @param dirUrl the directory URL.
      * @param flags whether to keep previous directories, and whether to reload, see OpenUrlFlags
      * @return @c true if successful, @c false otherwise (e.g. if @p dirUrl is invalid)
-     *
-     * @note clearDir(const QUrl &) is emitted since 5.79; before that it was clear(const QUrl &)
-     * which has been deprecated.
      */
-    virtual bool openUrl(const QUrl &dirUrl, OpenUrlFlags flags = NoFlags); // TODO KF6: remove virtual, change bool to void
+    bool openUrl(const QUrl &dirUrl, OpenUrlFlags flags = NoFlags); // TODO KF6: change bool to void
 
     /**
      * Stop listing all directories currently being listed.
@@ -121,11 +119,8 @@ public:
      * Emits canceled() if there was at least one job running.
      * Emits listingDirCanceled(const QUrl &) for each stopped job if there is more than one
      * directory being watched by this KCoreDirLister.
-     *
-     * @note listingDirCanceled(const QUrl &) is emitted since 5.79; before that it was
-     * canceled(const QUrl &) which has been deprecated.
      */
-    virtual void stop(); // TODO KF6: remove virtual
+    void stop();
 
     /**
      * Stop listing the given directory.
@@ -137,11 +132,18 @@ public:
      * No signal is emitted if there was no job running for @p dirUrl.
      *
      * @param dirUrl the directory URL
-     *
-     * @note listingDirCanceled(const QUrl &) is emitted since 5.79; before that it was
-     * canceled(const QUrl &) which has been deprecated.
      */
-    virtual void stop(const QUrl &dirUrl); // TODO KF6: remove virtual
+    void stop(const QUrl &dirUrl);
+
+    /**
+     * Stop listening for further changes in the given directory.
+     * When a new directory is opened with OpenUrlFlag::Keep the caller will keep being notified of file changes for all directories that were kept open.
+     * This call selectively removes a directory from sending future notifications to this KCoreDirLister.
+     *
+     * @param dirUrl the directory URL.
+     * @since 5.91
+     */
+    void forgetDirs(const QUrl &dirUrl);
 
     /**
      * @return @c true if the "delayed MIME types" feature was enabled
@@ -172,29 +174,31 @@ public:
      *
      * @param enable set to @c true to enable or @c false to disable
      */
-    virtual void setAutoUpdate(bool enable); // TODO KF6: remove virtual
+    void setAutoUpdate(bool enable);
 
     /**
-     * Checks whether hidden files (files whose name start with '.') will be shown.
+     * Checks whether hidden files (e.g. files whose name start with '.' on Unix) will be shown.
      * By default this option is disabled (hidden files are not shown).
      *
-     * @return @c true if dot files are shown, @c false otherwise
+     * @return @c true if hidden files are shown, @c false otherwise
      *
-     * @see setShowingDotFiles()
+     * @see setShowHiddenFiles()
+     * @since 5.100
      */
-    bool showingDotFiles() const;
+    bool showHiddenFiles() const;
 
     /**
-     * Toggles whether hidden files (files whose name start with '.') are shown, by default
-     * hidden files are not shown.
+     * Toggles whether hidden files (e.g. files whose name start with '.' on Unix) are shown/
+     * By default hidden files are not shown.
      *
      * You need to call emitChanges() afterwards.
      *
-     * @param showDotFiles set to @c true/false to show/hide hidden files respectively
+     * @param showHiddenFiles set to @c true/false to show/hide hidden files respectively
      *
-     * @see showingDotFiles()
+     * @see showHiddenFiles()
+     * @since 5.100
      */
-    virtual void setShowingDotFiles(bool showDotFiles); // TODO KF6: remove virtual
+    void setShowHiddenFiles(bool showHiddenFiles);
 
     /**
      * Checks whether this KCoreDirLister only lists directories or all items (directories and
@@ -214,7 +218,40 @@ public:
      *
      * @param dirsOnly set to @c true to list only directories
      */
-    virtual void setDirOnlyMode(bool dirsOnly); // TODO KF6: remove virtual
+    void setDirOnlyMode(bool dirsOnly);
+
+    /**
+     * Checks whether this KCoreDirLister requests the MIME type of files from the worker.
+     *
+     * Enabling this will tell the worker used for listing that it should try to
+     * determine the mime type of entries while listing them. This potentially
+     * reduces the speed at which entries are listed but ensures mime types are
+     * immediately available when an entry is added, greatly speeding up things
+     * like mime type filtering.
+     *
+     * By default this is disabled.
+     *
+     * @return @c true if the worker is asked for MIME types, @c false otherwise.
+     *
+     * @see setRequestMimeTypeWhileListing(bool)
+     *
+     * @since 5.82
+     */
+    bool requestMimeTypeWhileListing() const;
+
+    /**
+     * Toggles whether to request MIME types from the worker or in-process.
+     *
+     * @param request set to @c true to request MIME types from the worker.
+     *
+     * @note If this is changed while the lister is already listing a directory,
+     * it will only have an effect the next time openUrl() is called.
+     *
+     * @see requestMimeTypeWhileListing()
+     *
+     * @since 5.82
+     */
+    void setRequestMimeTypeWhileListing(bool request);
 
     /**
      * Returns the top level URL that is listed by this KCoreDirLister.
@@ -238,10 +275,10 @@ public:
     QList<QUrl> directories() const;
 
     /**
-     * Actually emit the changes made with setShowingDotFiles, setDirOnlyMode,
+     * Actually emit the changes made with setShowHiddenFiles, setDirOnlyMode,
      * setNameFilter and setMimeFilter.
      */
-    virtual void emitChanges(); // TODO KF6: remove virtual
+    void emitChanges();
 
     /**
      * Update the directory @p dirUrl. This method causes KCoreDirLister to @em only emit
@@ -253,7 +290,7 @@ public:
      *
      * @param dirUrl the directory URL
      */
-    virtual void updateDirectory(const QUrl &dirUrl); // TODO KF6: remove virtual
+    void updateDirectory(const QUrl &dirUrl);
 
     /**
      * Returns @c true if no I/O operation is currently in progress.
@@ -275,17 +312,17 @@ public:
      * @param url the item URL
      * @return the KFileItem
      */
-    virtual KFileItem findByUrl(const QUrl &url) const; // TODO KF6: remove virtual
+    KFileItem findByUrl(const QUrl &url) const;
 
     /**
      * Find an item by its name.
      * @param name the item name
      * @return the KFileItem
      */
-    virtual KFileItem findByName(const QString &name) const; // TODO KF6: remove virtual
+    KFileItem findByName(const QString &name) const;
 
     /**
-     * Set a name filter to only list items matching this name, e.g. "*.cpp".
+     * Set a name filter to only list items matching this name, e.g.\ "*.cpp".
      *
      * You can set more than one filter by separating them with whitespace, e.g
      * "*.cpp *.h".
@@ -295,7 +332,7 @@ public:
      * @param filter the new filter, QString() to disable filtering
      * @see matchesFilter
      */
-    virtual void setNameFilter(const QString &filter); // TODO KF6: remove virtual
+    void setNameFilter(const QString &filter);
 
     /**
      * Returns the current name filter, as set via setNameFilter()
@@ -317,7 +354,7 @@ public:
      * @see clearMimeFilter
      * @see matchesMimeFilter
      */
-    virtual void setMimeFilter(const QStringList &mimeList); // TODO KF6: remove virtual
+    void setMimeFilter(const QStringList &mimeList);
 
     /**
      * Filtering should be done with KFileFilter. This will be implemented in a later
@@ -331,7 +368,6 @@ public:
      * @param mimeList a list of MIME types
      * @see clearMimeFilter
      * @see matchesMimeFilter
-     * @internal
      */
     void setMimeExcludeFilter(const QStringList &mimeList);
 
@@ -342,7 +378,7 @@ public:
      *
      * @see setMimeFilter
      */
-    virtual void clearMimeFilter(); // TODO KF6: remove virtual
+    void clearMimeFilter();
 
     /**
      * Returns the list of MIME type based filters, as set via setMimeFilter().
@@ -350,26 +386,6 @@ public:
      */
     QStringList mimeFilters() const;
 
-    /**
-     * Checks whether @p name matches a filter in the list of name filters.
-     *
-     * @return @c true if @p name matches a filter in the list, otherwise @c false.
-     *
-     * @see setNameFilter()
-     */
-    bool matchesFilter(const QString &name) const;
-
-    /**
-     * Checks whether @p mimeType matches a filter in the list of MIME types.
-     *
-     * @param mimeType the MIME type to find in the filter list
-     *
-     * @return @c true if @p mimeType matches a filter in the list, otherwise @c false
-     *
-     * @see setMimeFilter.
-     */
-    bool matchesMimeFilter(const QString &mimeType) const;
-
     /**
      * Used by items() and itemsForDir() to specify whether you want
      * all items for a directory or just the filtered ones.
@@ -424,10 +440,32 @@ public:
      *
      * If you really need a KFileItem for this URL in all cases, then use KIO::stat() instead.
      *
-     * @since 4.2
      */
     static KFileItem cachedItemForUrl(const QUrl &url);
 
+    /**
+     * Checks whether auto error handling is enabled.
+     * If enabled, it will show an error dialog to the user when an
+     * error occurs (assuming the application links to KIOWidgets).
+     * It is turned on by default.
+     * @return @c true if auto error handling is enabled, @c false otherwise
+     * @see setAutoErrorHandlingEnabled()
+     * @since 5.82
+     */
+    bool autoErrorHandlingEnabled() const;
+
+    /**
+     * Enable or disable auto error handling.
+     * If enabled, it will show an error dialog to the user when an
+     * error occurs. It is turned on by default.
+     * @param enable true to enable auto error handling, false to disable
+     * @param parent the parent widget for the error dialogs, can be @c nullptr for
+     *               top-level
+     * @see autoErrorHandlingEnabled()
+     * @since 5.82
+     */
+    void setAutoErrorHandlingEnabled(bool enable);
+
 Q_SIGNALS:
     /**
      * Tell the view that this KCoreDirLister has started to list @p dirUrl. Note that this
@@ -443,20 +481,7 @@ Q_SIGNALS:
     /**
      * Tell the view that listing is finished. There are no jobs running anymore.
      */
-    void completed(); // clazy:exclude=overloaded-signal
-
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
-    /**
-     * Tell the view that the listing of the directory @p dirUrl is finished.
-     * There might be other running jobs left.
-     *
-     * @param dirUrl the directory URL
-     *
-     * @deprecated since 5.79, use KCoreDirLister::listingDirCompleted(const QUrl &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 79, "Use KCoreDirLister::listingDirCompleted(const QUrl &)")
-    void completed(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
-#endif
+    void completed();
 
     /**
      * Tell the view that the listing of the directory @p dirUrl is finished.
@@ -471,20 +496,7 @@ Q_SIGNALS:
     /**
      * Tell the view that the user canceled the listing. No running jobs are left.
      */
-    void canceled(); // clazy:exclude=overloaded-signal
-
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
-    /**
-     * Tell the view that the listing of the directory @p dirUrl was canceled.
-     * There might be other running jobs left.
-     *
-     * @param dirUrl the directory URL
-     *
-     * @deprecated since 5.79, use KCoreDirLister::listingDirCanceled(const QUrl &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 79, "use KCoreDirLister::listingDirCanceled(const QUrl &)")
-    void canceled(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
-#endif
+    void canceled();
 
     /**
      * Tell the view that the listing of the directory @p dirUrl was canceled.
@@ -496,47 +508,19 @@ Q_SIGNALS:
      */
     void listingDirCanceled(const QUrl &dirUrl);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 80)
-    /**
-     * Signal a redirection.
-     * Only emitted if there's just one directory to list, i.e. most
-     * probably openUrl() has been called without OpenUrlFlag::Keep.
-     *
-     * @param dirUrl the new URL
-     *
-     * @deprecated since 5.80, use redirection(const QUrl &, const QUrl &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 80, "Use redirection(const QUrl &, const QUrl &)")
-    void redirection(const QUrl &_url); // clazy:exclude=overloaded-signal
-#endif
-
     /**
      * Signals a redirection.
      *
      * @param oldUrl the original URL
      * @param newUrl the new URL
      */
-    void redirection(const QUrl &oldUrl, const QUrl &newUrl); // clazy:exclude=overloaded-signal
+    void redirection(const QUrl &oldUrl, const QUrl &newUrl);
 
     /**
-     * Signals to the view to remove all items (when e.g. going from dirA to dirB).
+     * Signals to the view to remove all items (when e.g.\ going from dirA to dirB).
      * Make sure to connect to this signal to avoid having duplicate items in the view.
      */
-    void clear(); // clazy:exclude=overloaded-signal
-
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
-    /**
-     * Signals to the view to clear all items from directory @p dirUrl.
-     *
-     * This is only emitted if the lister is holding more than one directory.
-     *
-     * @param dirUrl the directory that the view should clear all items from
-     *
-     * @deprecated since 5.79, use clearDir(const QUrl &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 79, "Use clearDir(const QUrl &)")
-    void clear(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
-#endif
+    void clear();
 
     /**
      * Signals to the view to clear all items from directory @p dirUrl.
@@ -562,13 +546,13 @@ Q_SIGNALS:
      * but itemsAdded also passes the url of the parent directory.
      *
      * @param items a list of new items
-     * @since 4.2
      */
     void itemsAdded(const QUrl &directoryUrl, const KFileItemList &items);
 
     /**
      * Send a list of items filtered-out by MIME type.
      * @param items the list of filtered items
+     *
      */
     void itemsFilteredByMime(const KFileItemList &items);
 
@@ -622,76 +606,19 @@ Q_SIGNALS:
      */
     void speed(int bytes_per_second);
 
+    /**
+     * Emitted if listing a directory fails with an error.
+     * A typical implementation in a widgets-based application
+     * would show a message box by calling this in a slot connected to this signal:
+     * <tt>job->uiDelegate()->showErrorMessage()</tt>
+     * Many applications might prefer to embed the error message though
+     * (e.g. by using the KMessageWidget class, from the KWidgetsAddons Framework).
+     * @param the job with an error
+     * @since 5.82
+     */
+    void jobError(KIO::Job *job);
+
 protected:
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 3)
-    /// @deprecated Since 4.3, and unused, ignore this
-    enum Changes { NONE = 0, NAME_FILTER = 1, MIME_FILTER = 2, DOT_FILES = 4, DIR_ONLY_MODE = 8 };
-#endif
-
-    /**
-     * Called for every new item before emitting newItems().
-     * You may reimplement this method in a subclass to implement your own
-     * filtering.
-     * The default implementation filters out ".." and everything not matching
-     * the name filter(s)
-     * @return @c true if the item is "ok".
-     *         @c false if the item shall not be shown in a view, e.g.
-     * files not matching a pattern *.cpp ( KFileItem::isHidden())
-     * @see matchesFilter
-     * @see setNameFilter
-     */
-    virtual bool matchesFilter(const KFileItem &) const;
-
-    /**
-     * Called for every new item before emitting newItems().
-     * You may reimplement this method in a subclass to implement your own
-     * filtering.
-     * The default implementation filters out ".." and everything not matching
-     * the name filter(s)
-     * @return @c true if the item is "ok".
-     *         @c false if the item shall not be shown in a view, e.g.
-     * files not matching a pattern *.cpp ( KFileItem::isHidden())
-     * @see matchesMimeFilter
-     * @see setMimeFilter
-     */
-    virtual bool matchesMimeFilter(const KFileItem &) const;
-
-    /**
-     * Called by the public matchesFilter() to do the
-     * actual filtering. Those methods may be reimplemented to customize
-     * filtering.
-     * @param name the name to filter
-     * @param filters a list of regular expressions for filtering
-     */
-    // TODO KF6 remove
-    virtual bool doNameFilter(const QString &name, const QList<QRegExp> &filters) const;
-
-    /**
-     * Called by the public matchesMimeFilter() to do the
-     * actual filtering. Those methods may be reimplemented to customize
-     * filtering.
-     * @param mimeType the MIME type to filter
-     * @param filters the list of MIME types to filter
-     */
-    // TODO KF6 remove
-    virtual bool doMimeFilter(const QString &mimeType, const QStringList &filters) const;
-
-    /**
-     * Reimplement to customize error handling
-     */
-    virtual void handleError(KIO::Job *);
-
-    // Not _ENABLED_ because this is a virtual method
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 81)
-    /**
-     * Reimplement to customize error handling
-     * @deprecated since 5.81, handleError() is emitted instead for the two
-     * cases where handleErrorMessage was emitted (invalid URL, protocol not supporting listing).
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 81, "Use handleError() instead")
-    virtual void handleErrorMessage(const QString &message);
-#endif
-
     /**
      * Reimplemented by KDirLister to associate windows with jobs
      * @since 5.0
